@@ -34,6 +34,17 @@ AQSys.mathDesc <- function(mathDesc) {
         P1 * log(P2 + XC) + P3
       }
     },
+    "tang" = {
+      Fn <- function(CoefSET, XC) {
+        # equation's parameters
+        P1 <- CoefSET[1]
+        P2 <- CoefSET[2]
+        P3 <- CoefSET[3]
+        P4 <- CoefSET[4]
+        # tello's equation
+        exp(P1 + P2 * (XC ^ (0.5)) + P3 * XC + P4 * (XC ^ 2))
+      }
+    },
     # if user selects an option not available, it triggers an error
     # (check AQSys.err.R for details)
     AQSys.err("0")
@@ -46,10 +57,20 @@ AQSys.mathDesc <- function(mathDesc) {
 #'@export AQSysList
 #'@title Aqueous Systems Descriptors already implemented
 #'@description The function returns a list of all mathematical descriptors available at the time.
-AQSysList <- function() {
+#' @param npars Logic option to return a List variable containing the number of required parameters for each equation.
+AQSysList <- function(npars=FALSE) {
   # a new entry in updte must be added for each new equation implemmented in AQSys.mathDesc()
   # updte entries' name must match AQSys.mathDesc switch options
-  updte <- c("merchuk", "murugesan", "tello")
+  updte <- if(npars) {
+    list(
+      "merchuk" = 3,
+      "murugesan" = 3,
+      "tello" = 3,
+      "tang" = 4
+    )
+  } else {
+    list("merchuk", "murugesan", "tello", "tang")
+  }
   # return list
   return(updte)
 }
